@@ -116,18 +116,14 @@ class ArtifactFormat(SubDir):
         uuid = self.root().next_upload()
         await self.root().update_upload(uuid, read)
         await self.root().finalize_upload(uuid, digest)
-        # avoid counting disk usage twice (already counted in update_upload()
-        self.link_file(digest, relpath, ignore_quota=True)
+        self.link_file(digest, relpath)
 
-    def link_file(self, digest: str, relpath: str, ignore_quota: bool = False):
+    def link_file(self, digest: str, relpath: str):
         was_dirty = self.is_dirty()
         self.set_dirty(True)
         try:
             path = self._check_filepath(relpath)
-            if ignore_quota:
-                self.root().link_blob_ignore_quota(digest, path)
-            else:
-                self.root().link_blob(digest, path)
+            self.root().link_blob(digest, path)
         except:
             if not was_dirty:
                 self.set_dirty(False)
