@@ -29,25 +29,31 @@ class ArtifactView(BaseView):
         if "product" in match:
             if create:
                 raise web.HTTPBadRequest(reason="Uploading products is not supported")
-            fmt = (
-                self.repo()
-                .get_product(match["product"])
-                .get_variant(match["variant"])
-                .get_branch(match["product_branch"])
-                .get_version(match["version"], access_cb)
-                .get_format(match["format"])
-            )
+            try:
+                fmt = (
+                    self.repo()
+                    .get_product(match["product"])
+                    .get_variant(match["variant"])
+                    .get_branch(match["product_branch"])
+                    .get_version(match["version"], access_cb)
+                    .get_format(match["format"])
+                )
+            except FileNotFoundError as e:
+                raise web.HTTPNotFound() from e
         else:
-            job = (
-                self.repo()
-                .get_branch(match["branch"])
-                .get_tag(match["tag"], access_cb)
-                .get_job(match["job"])
-            )
+            if create and match["tag"] in ("latest", "stable", "oldstable"):
+                raise web.HTTPMethodNotAllowed(self.request.method, ["GET"])
+            try:
+                job = (
+                    self.repo()
+                    .get_branch(match["branch"])
+                    .get_tag(match["tag"], access_cb)
+                    .get_job(match["job"])
+                )
+            except FileNotFoundError as e:
+                raise web.HTTPNotFound() from e
             fmt = job.get_format(match["format"])
             if create:
-                if match["tag"] == "latest":
-                    raise web.HTTPMethodNotAllowed(self.request.method, ["GET"])
                 if match["format"] == "container":
                     agent = self.request.headers.get("User-Agent", "")
                     # allow uploading directly between dlrepo servers
