@@ -112,6 +112,9 @@ class TarResponse(web.StreamResponse):
             await self.write(buf)  # includes http chunk header & trailer
             tar_offset += len(buf)
 
+            if info.size == 0:
+                continue
+
             fobj = await loop.run_in_executor(None, path.open, "rb")
             try:
                 # loop.sendfile works on the raw transport class and does not include
